@@ -9,34 +9,37 @@ from jet_bridge_base.views.base.api import BaseAPIView
 
 class RegisterView(BaseAPIView):
 
-    def get(self, *args, **kwargs):
+    def get(self, request, *args, **kwargs):
         if not settings.PROJECT:
             return Response('Project name is not set', status=HTTP_400_BAD_REQUEST)
 
         if not settings.TOKEN:
             return Response('Project token is not set', status=HTTP_400_BAD_REQUEST)
 
-        token = self.request.get_argument('token', '')
-        install_type = self.request.get_argument('install_type', '')
+        token = request.get_argument('token', '')
+        environment_type = settings.ENVIRONMENT_TYPE
 
-        if settings.WEB_BASE_URL.startswith('https') and not self.request.full_url().startswith('https'):
+        if settings.WEB_BASE_URL.startswith('https') and not request.full_url().startswith('https'):
             web_base_url = 'http{}'.format(settings.WEB_BASE_URL[5:])
         else:
             web_base_url = settings.WEB_BASE_URL
 
-        if token:
-            url = '{}/projects/register/{}'.format(web_base_url, token)
+        if settings.ENVIRONMENT:
+            url = '{}/builder/{}/{}/resources/database/create/'.format(web_base_url, settings.PROJECT, settings.ENVIRONMENT)
         else:
-            url = '{}/projects/register'.format(web_base_url)
+            url = '{}/builder/{}/resources/database/create/'.format(web_base_url, settings.PROJECT)
 
         parameters = [
-            ['project', settings.PROJECT],
-            ['referrer', self.request.full_url().encode('utf8')],
+            ['engine', settings.DATABASE_ENGINE],
+            ['referrer', request.full_url().encode('utf8')],
         ]
 
-        if install_type:
-            parameters.append(['install_type', install_type])
+        if token:
+            parameters.append(['token', token])
+
+        if environment_type:
+            parameters.append(['environment_type', environment_type])
 
         query_string = '&'.join(map(lambda x: '{}={}'.format(x[0], quote(x[1])), parameters))
 
-        return RedirectResponse('%s?%s' % (url, query_string))
+        return RedirectResponse('%s#%s' % (url, query_string))
